Function partial_sha256_var_interstitial
pub fn partial_sha256_var_interstitial<let N: u32>(
h: [u32; 8],
msg: [u8; N],
message_size: u32,
) -> [u32; 8]
pub fn partial_sha256_var_interstitial<let N: u32>(
h: [u32; 8],
msg: [u8; N],
message_size: u32,
) -> [u32; 8]
Given some state of a partially computed sha256 hash and part of the preimage, continue hashing @notice used for complex/ recursive offloading of post-partial hashing
@param N - the maximum length of the message to hash @param h - the intermediate hash state @param msg - the preimage to hash @param message_size - the actual length of the preimage to hash @return the intermediate hash state after compressing in msg to h